# Early stages

## throwing ideas

When we decided to collaborate on this project, we sat down and brainstormed fascinating and innovative ideas. Some of them were incredibly technical, such as the concept of creating a computer within the Game of Life and then devising a programming language for it. However, that proved to be exceedingly intricate for our skillset. Additionally, we entertained the notion of creating a fluid simulator with accurate physics, but that also proved to be overly ambitious for us.

Ultimately, after careful consideration and evaluation of our capabilities, we settled on creating an evolution simulator. This idea was challenging, but not unmanageable. We were excited to explore the intricacies of the natural world and replicate the processes of evolution through a simulation.
